@@ -19,6 +19,37 @@ PY2 = sys.version_info[0] == 2
 PY3 = sys.version_info[0] == 3
 FILESYSTEM_ENCODING = sys.getfilesystemencoding()
 
+# Control some tweakables that will be removed finally.
+ENCODE_ENVIRONMENT=True
+ENCODE_ARGS=False
+
+# Want bytes encoded as utf-8 for both names and values.
+def encode_for_env_var(value):
+    if isinstance(value, str):
+        return value
+    if sys.version_info[0] == 2:
+        _unicode = unicode
+    else:
+        _unicode = str
+    if isinstance(value, (str, _unicode)):
+        try:
+            return bytes(value, encoding='utf-8')
+        except:
+            return value.encode('utf-8')
+    return str(value)
+
+
+def encode_environment(env):
+    if ENCODE_ENVIRONMENT:
+        env = {encode_for_env_var(k): encode_for_env_var(v) for k, v in iteritems(env)}
+    return env
+
+
+def encode_arguments(arguments):
+    if ENCODE_ARGS:
+        arguments = {encode_for_env_var(arg) for arg in arguments}
+    return arguments
+
 
 # #############################
 # equivalent commands
@@ -59,7 +90,19 @@ if PY3:  # pragma: py2 no cover
         JSONDecodeError = ValueError
 elif PY2:  # pragma: py3 no cover
     from collections import Mapping, Sequence
-    from cStringIO import StringIO
+    # We cannot use cStringIO if we ever hope to print Unicode.
+    # https://docs.python.org/2.7/library/stringio.html
+    # Unlike the memory files implemented by the StringIO module, those provided
+    # by this module are not able to accept Unicode strings that cannot be encoded
+    # as plain ASCII strings.
+    # print(io.StringIO(u'fooáßñ固').read())
+    # fooáßñ固
+    # vs:
+    # print(cStringIO.StringIO(u'fooáßñ固').read())
+    # Traceback (most recent call last):
+    #   File "<stdin>", line 1, in <module>
+    # UnicodeEncodeError: 'ascii' codec can't encode characters in position 3-6: ordinal not in range(128)
+    from io import StringIO
     from itertools import izip as zip, izip_longest as zip_longest
     JSONDecodeError = ValueError
 
@@ -124,10 +167,10 @@ from io import open as io_open  # NOQA
 
 def open(file, mode='r', buffering=-1, encoding=None, errors=None, newline=None, closefd=True):
     if 'b' in mode:
-        return io_open(ensure_fs_path_encoding(file), str(mode), buffering=buffering,
+        return io_open(file, str(mode), buffering=buffering,
                        errors=errors, newline=newline, closefd=closefd)
     else:
-        return io_open(ensure_fs_path_encoding(file), str(mode), buffering=buffering,
+        return io_open(file, str(mode), buffering=buffering,
                        encoding=encoding or 'utf-8', errors=errors, newline=newline,
                        closefd=closefd)
 
@@ -177,7 +220,9 @@ def _init_stream_encoding(stream):
         return stream
     from codecs import getwriter
     from locale import getpreferredencoding
+    # No no no.
     encoding = getpreferredencoding()
+    # encoding = 'UTF-8'
     try:
         writer_class = getwriter(encoding)
     except LookupError:
@@ -234,6 +279,18 @@ def ensure_unicode(value):
 
 def ensure_fs_path_encoding(value):
     try:
-        return value.decode(FILESYSTEM_ENCODING)
+        return value.encode(FILESYSTEM_ENCODING)
     except AttributeError:
         return value
+    except UnicodeEncodeError:
+        return value
+
+
+def ensure_utf8_encoding(value):
+    try:
+        return value.encode('utf-8')
+    except AttributeError:
+        return value
+    except UnicodeEncodeError:
+        return value
+
