@@ -42,6 +42,10 @@ from random import randint
 import re
 import sys
 
+try:
+    FileNotFoundError
+except NameError:
+    FileNotFoundError = IOError
 
 from .. import CONDA_PACKAGE_ROOT, CondaError, __version__ as CONDA_VERSION
 from .._vendor.auxlib.compat import Utf8NamedTemporaryFile
@@ -646,7 +650,7 @@ def run_plan_elevated(plan):
                     rm_rf(temp_path)
 
         else:
-            stdin = json.dumps(plan)
+            stdin = json.dumps(plan, ensure_ascii=False, default=lambda x: x.__dict__)
             result = subprocess_call(
                 'sudo %s -m conda.core.initialize' % sys.executable,
                 env={},
@@ -975,8 +979,13 @@ def init_fish_user(target_path, conda_prefix, reverse):
     # target_path: ~/.config/config.fish
     user_rc_path = target_path
 
-    with open(user_rc_path) as fh:
-        rc_content = fh.read()
+    try:
+        with open(user_rc_path) as fh:
+            rc_content = fh.read()
+    except FileNotFoundError:
+        rc_content = ''
+    except:
+        raise
 
     rc_original_content = rc_content
 
@@ -1041,6 +1050,9 @@ def init_fish_user(target_path, conda_prefix, reverse):
             print(target_path)
             print(make_diff(rc_original_content, rc_content))
         if not context.dry_run:
+            # Make the directory if needed.
+            if not exists(dirname(user_rc_path)):
+                mkdir_p(dirname(user_rc_path))
             with open(user_rc_path, 'w') as fh:
                 fh.write(rc_content)
         return Result.MODIFIED
